Value<T> class
Used to configure the SwitchCondition Widget.
The value will be compared to the value of the SwitchCondition.
If the values are equal the provided builder will be shown.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited